#!/usr/bin/env bash

bin=`dirname "${BASH_SOURCE-$0}"`
bin=`cd "$bin"; pwd`
USERNAME=`whoami`
WORKER_PREFIX=`dirname "$bin"`
WORKER_CONF_DIR="${WORKER_PREFIX}/conf"
WORKER_LIB_DIR="${WORKER_PREFIX}/lib"
WORKER_LOG_DIR="${WORKER_PREFIX}/logs"

if [ ! -d "${WORKER_LOG_DIR}" ]; then
    mkdir -p ${WORKER_LOG_DIR}
fi

if [ ! -d "~/logs/schedulerx/" ]; then
    mkdir -p ~/logs/schedulerx/
fi

PID="${WORKER_PREFIX}/agent.pid"

if [ -x "${JAVA_HOME}/bin/java" ]; then
    JAVA="${JAVA_HOME}/bin/java"
else
    JAVA=`which java`
fi

if [ ! -x "${JAVA}" ]; then
    echo "Could not find any executable java binary. Please install java in your PATH or set JAVA_HOME"
    exit 1
fi

replace() {
    if [ -n "${SCHEDULERX_ENDPOINT}" ]; then
        sed -i "s/{SCHEDULERX_ENDPOINT}/${SCHEDULERX_ENDPOINT}/g" ${WORKER_CONF_DIR}/agent.properties
    else
        sed -i "s/{SCHEDULERX_ENDPOINT}//g" ${WORKER_CONF_DIR}/agent.properties
    fi

    if [ -n "${SCHEDULERX_DOMAINNAME}" ]; then
        sed -i "s/{SCHEDULERX_DOMAINNAME}/${SCHEDULERX_DOMAINNAME}/g" ${WORKER_CONF_DIR}/agent.properties
    else
        sed -i "s/{SCHEDULERX_DOMAINNAME}//g" ${WORKER_CONF_DIR}/agent.properties
    fi

    if  [ -n "${SCHEDULERX_NAMESPACE}" ]; then    
        sed -i "s/{SCHEDULERX_NAMESPACE}/${SCHEDULERX_NAMESPACE}/g" ${WORKER_CONF_DIR}/agent.properties
    fi

    if [ -n "${SCHEDULERX_GROUPID}" ]; then
        sed -i "s/{SCHEDULERX_GROUPID}/${SCHEDULERX_GROUPID}/g" ${WORKER_CONF_DIR}/agent.properties
    fi

    if [ -n "${SCHEDULERX_APPKEY}" ]; then
        sed -i "s#{SCHEDULERX_APPKEY}#${SCHEDULERX_APPKEY}#g" ${WORKER_CONF_DIR}/agent.properties
    fi
}

replace

MAIN_CLASS="com.alibaba.schedulerx.worker.SchedulerxWorker"

JAVA_OPTS="-Dproject.name=schedulerxAgent -XX:+UseConcMarkSweepGC -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=${WORKER_LOG_DIR}  -XX:+DoEscapeAnalysis"
if [ -n "${SCHEDULERX_STARTER_MODE}" ]; then
    JAVA_OPTS="${JAVA_OPTS} -Dschedulerx.stater.mode=${SCHEDULERX_STARTER_MODE}"
fi
echo ${JAVA_OPTS}

if [ -f ${PID} ]; then
    TARGET_PID=`cat ${PID}`
    echo "Agent(pid:${TARGET_PID}) is still running, start failed!"
    exit 1
fi

nohup ${JAVA} ${JAVA_OPTS} -cp .:${WORKER_LIB_DIR}/* \
    ${MAIN_CLASS} ${WORKER_CONF_DIR}/agent.properties > ~/logs/schedulerx/worker.log 2>&1 < /dev/null &

echo $! > ${PID}
TARGET_PID=`cat ${PID}`
echo "Agent(pid:${TARGET_PID}) started successful."

